==> vue-i18n-extract-0.4.9.tgz: package/dist-src/Api.js <==
import path from 'path';
import fs from 'fs';
import { readVueFiles, readLangFiles, extractI18nItemsFromVueFiles, extractI18nItemsFromLanguageFiles, diffParsedSources, logMissingKeys, logUnusedKeys, } from './library/index';
export default class VueI18NExtract {
    parseVueFiles(vueFilesPath) {
        const filesList = readVueFiles(vueFilesPath);
        return extractI18nItemsFromVueFiles(filesList);
    }
    parseLanguageFiles(languageFilesPath) {
        const filesList = readLangFiles(languageFilesPath);
        return extractI18nItemsFromLanguageFiles(filesList);
    }
    createI18NReport(vueFiles, languageFiles) {
        const parsedVueFiles = this.parseVueFiles(vueFiles);
        const parsedLanguageFiles = this.parseLanguageFiles(languageFiles);
        return this.extractI18NReport(parsedVueFiles, parsedLanguageFiles);
    }
    extractI18NReport(parsedVueFiles, parsedLanguageFiles) {
        const missingKeys = [];
        const unusedKeys = [];
        Object.keys(parsedLanguageFiles).forEach((language) => {
            const languageMissingKeys = diffParsedSources(parsedVueFiles, parsedLanguageFiles[language])
                .map((item) => (Object.assign({}, item, { language })));
            missingKeys.push(...languageMissingKeys);
            const languageUnusedKeys = diffParsedSources(parsedLanguageFiles[language], parsedVueFiles)
                .map((item) => (Object.assign({}, item, { language })));
            unusedKeys.push(...languageUnusedKeys);
        });
        return {
            missingKeys,
            unusedKeys,
        };
    }
    logI18NReport(report) {
        logMissingKeys(report.missingKeys);
        logUnusedKeys(report.unusedKeys);
    }
    writeReportToFile(report, writePath) {
        const reportString = JSON.stringify(report);
        fs.writeFile(path.resolve(process.cwd(), writePath), reportString, (err) => {
            if (err) {
                throw err;
            }
            // tslint:disable-next-line
            console.log(`The report has been has been saved to ${writePath}`);
        });
    }
}

==> vue-i18n-extract-0.4.10.tgz: package/dist-src/Api.js <==
import path from 'path';
import fs from 'fs';
import { readVueFiles, readLangFiles, extractI18nItemsFromVueFiles, extractI18nItemsFromLanguageFiles, diffParsedSources, logMissingKeys, logUnusedKeys, } from './library/index';
export default class VueI18NExtract {
    parseVueFiles(vueFilesPath) {
        const filesList = readVueFiles(vueFilesPath);
        return extractI18nItemsFromVueFiles(filesList);
    }
    parseLanguageFiles(languageFilesPath) {
        const filesList = readLangFiles(languageFilesPath);
        return extractI18nItemsFromLanguageFiles(filesList);
    }
    createI18NReport(vueFiles, languageFiles) {
        const parsedVueFiles = this.parseVueFiles(vueFiles);
        const parsedLanguageFiles = this.parseLanguageFiles(languageFiles);
        return this.extractI18NReport(parsedVueFiles, parsedLanguageFiles);
    }
    extractI18NReport(parsedVueFiles, parsedLanguageFiles) {
        const missingKeys = [];
        const unusedKeys = [];
        Object.keys(parsedLanguageFiles).forEach((language) => {
            const languageMissingKeys = diffParsedSources(parsedVueFiles, parsedLanguageFiles[language])
                .map((item) => (Object.assign({}, item, { language })));
            missingKeys.push(...languageMissingKeys);
            const languageUnusedKeys = diffParsedSources(parsedLanguageFiles[language], parsedVueFiles)
                .map((item) => (Object.assign({}, item, { language })));
            unusedKeys.push(...languageUnusedKeys);
        });
        return {
            missingKeys,
            unusedKeys,
        };
    }
    logI18NReport(report) {
        logMissingKeys(report.missingKeys);
        logUnusedKeys(report.unusedKeys);
    }
    async writeReportToFile(report, writePath) {
        const reportString = JSON.stringify(report);
        return fs.writeFile(path.resolve(process.cwd(), writePath), reportString, (err) => {
            if (err) {
                throw err;
            }
            // tslint:disable-next-line
            console.log(`The report has been has been saved to ${writePath}`);
        });
    }
}
